from django.contrib import admin
from django.utils.html import format_html

from ..models.exercise_plan_template import ExercisePlanTemplateTranslation, ExercisePlanTemplateDetail, ExercisePlanTemplate


class TranslationPlanTemplateInline(admin.TabularInline):
    model = ExercisePlanTemplateTranslation
    fields = ('language_code', 'name', 'description')
    extra = 0


class TranslationPlanTemplateDetailInline(admin.TabularInline):
    model = ExercisePlanTemplateDetail
    verbose_name = 'name'
    fields = ('exercise_type','sort')
    extra = 0
    ordering = ('sort',)


class ExercisePlanTemplateAdmin(admin.ModelAdmin):
    list_display = ('name_colored', 'template_type')
    search_fields = ['name']

    def name_colored(self, obj):
        color_code = 'C20000'
        html = '<span style="color: #{};">{}</span>˓→'.format(color_code, obj.name)
        return format_html(html)

    name_colored.admin_order_field = 'name'
    name_colored.short_description = 'name'

    inlines = [
        TranslationPlanTemplateInline,
        TranslationPlanTemplateDetailInline
    ]


class ExercisePlanTemplateDetailAdmin(admin.ModelAdmin):
    list_display = ('get_plan', 'get_exercise_type', 'quantity', 'quantity_unit_quantity', 'rest_time',)
    list_editable = ('serie', 'quantity', 'quantity_unit_quantity', 'rest_time')

    def get_plan(self, obj):
        return obj.exercise_plan_template.name

    def get_exercise_type(self, obj):
        return obj.exercise_type.name


admin.site.register(ExercisePlanTemplate, ExercisePlanTemplateAdmin)
admin.autodiscover()
