from django.contrib import admin

from django.db import models
from django_admin_json_editor import JSONEditorWidget

from ..models.tutorial import TutorialTranslation, Tutorial, TutorialSteps


class TranslationTutorialInline(admin.TabularInline):
    model = TutorialTranslation
    fields = ('language_code', 'tutorial_text')
    extra = 0


DATA_SCHEMA = {
    'type': 'object',
    'title': 'Control for TutorialStep',
    'properties': {
        'direction': {
            'title': 'direction',
            'type': 'string',
            'enum': ['up', 'down', 'left', 'right']
        },
        'top': {
            'title': 'Top',
            'type': 'integer',
        },
        'left': {
            'title': 'Left',
            'type': 'integer',
        },
        'show_bubble': {
            'title': 'Show Bubble',
            'type': 'boolean',
        },
        'bubble_x': {
            'title': 'Bubble X',
            'type': 'integer',
        },
        'bubble_y': {
            'title': 'Bubble Y',
            'type': 'integer',
        },
        'bubble_width': {
            'title': 'Bubble Width',
            'type': 'integer',
        },
        'bubble_height': {
            'title': 'Bubble Height',
            'type': 'integer',
        },
        'show_check_text': {
            'title': 'Show Check Text',
            'type': 'boolean',
        },
        'parent': {
            'title': 'parent',
            'type': 'integer',
        },
    },
}


class TutorialStepsAdmin(admin.ModelAdmin):
    list_display = ('tutorial_step_id', 'tutorial', 'check_text', 'step')
    list_filter = ('tutorial__name',)
    fields = ('tutorial', 'step', "tutorial_text",  "check_text", "condition")
    list_editable = ('step',)
    ordering = ('tutorial_step_id',)
    formfield_overrides = {
        models.TextField: {
            'widget': JSONEditorWidget(DATA_SCHEMA, collapsed=False)
        },
    }

    def copy_attributes(self, request, queryset):
        for objectAttr in reversed(queryset):
            objectAttr.pk = None
            objectAttr.step = objectAttr.step + 1
            objectAttr.save()

    copy_attributes.short_description = "Clone the selected TutorialStep"

    actions = [copy_attributes]

    inlines = [
        TranslationTutorialInline,
    ]


class TutorialAdmin(admin.ModelAdmin):
    list_display = ('name',)
    fields = ('name',)


#admin.site.register(Tutorial, TutorialAdmin)
#admin.site.register(TutorialSteps, TutorialStepsAdmin)
#admin.autodiscover()
