from django.db import models
from django.utils.translation import ugettext_lazy as _

from .enums import LanguageTypes

class Sport(models.Model):
    sport_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=200, help_text='Unique name',
                            verbose_name=_("name"))

    class Meta:
        db_table = 'sport'
        verbose_name = _("Sport")
        verbose_name_plural = _("Sports")

    def __str__(self):
        return self.name


class SportTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    sport = models.ForeignKey(Sport, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    sport_name = models.CharField(max_length=200, help_text='Unique description name',
                            verbose_name=_("name"))

    class Meta:
        db_table = 'sport_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")
