from django.db import models
from django.utils.translation import ugettext_lazy as _
from ckeditor.fields import RichTextField

from .enums import LanguageTypes


class Tutorial(models.Model):
    tutorial_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=100, help_text='The name should be in English here',
                            verbose_name=_("name"))

    class Meta:
        db_table = 'tutorial'
        verbose_name = _("Tutorial")
        verbose_name_plural = _("Tutorials")

    def __str__(self):
        return self.name


class TutorialSteps(models.Model):
    tutorial_step_id = models.AutoField(primary_key=True)
    tutorial = models.ForeignKey(Tutorial, on_delete=models.CASCADE)
    step = models.IntegerField(help_text="Tutorial Step")
    tutorial_text = RichTextField()

    check_text = models.CharField(max_length=50, blank=True, null=True, help_text="Only for programmers!")
    condition = models.TextField(blank=True, null=True, help_text="Only for programmers!")

    class Meta:
        db_table = 'tutorial_steps'
        verbose_name = _("Tutorial Step")
        verbose_name_plural = _("Tutorial Steps")


class TutorialTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    tutorial_step = models.ForeignKey(TutorialSteps, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    tutorial_text = RichTextField()

    class Meta:
        db_table = 'tutorial_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.tutorial_text
